@@ -6,8 +6,8 @@
 ;; URL: https://github.com/precompute/hyperstitional-themes
 ;; Created: April 16, 2024
 ;; Modified: September 15, 2025
-;; Package-Version: 3.1.1
-;; Package-Revision: 4004a9ca832c
+;; Package-Version: 3.2.1
+;; Package-Revision: 37218686986a
 ;; Package-Requires: ((emacs "24.1"))
 
 ;; This program is free software: you can redistribute it and/or modify
@@ -564,6 +564,11 @@ Returns a color in hex as a string."
      `(vertico-group-title ((,class (:foreground ,c6 :background ,c6-light :inherit variable-pitch))))
      `(vertico-quick1      ((,class (:background ,c0-light :foreground ,c0))))
      `(vertico-quick2      ((,class (:background ,c6-light :foreground ,c6))))
+     `(vertico-posframe-border ((,class (:background ,c6))))
+     `(vertico-posframe-border-2 ((,class (:background ,c4))))
+     `(vertico-posframe-border-3 ((,class (:background ,c2))))
+     `(vertico-posframe-border-4 ((,class (:background ,c0))))
+     `(vertico-posframe-border-fallback ((,class (:background ,c1))))
 
 ;;;;;; olivetti
      `(olivetti-fringe ((,class (:background ,bg))))
@@ -1176,6 +1181,11 @@ Returns a color in hex as a string."
      `(vertico-group-title ((,class (:foreground ,ra :background ,rg :inherit variable-pitch))))
      `(vertico-quick1      ((,class (:background ,ba :foreground ,bg))))
      `(vertico-quick2      ((,class (:background ,ga :foreground ,gg))))
+     `(vertico-posframe-border ((,class (:background ,ra))))
+     `(vertico-posframe-border-2 ((,class (:background ,ga))))
+     `(vertico-posframe-border-3 ((,class (:background ,ba))))
+     `(vertico-posframe-border-4 ((,class (:background ,wa))))
+     `(vertico-posframe-border-fallback ((,class (:background ,gd))))
 
 ;;;;;; ediff
      `(ediff-odd-diff-Ancestor ((,class (:background ,rg))))
